/**
 * 用户类
 */
import ext from './extend.js';
import api from './api.js';

export default {
    /**
     * 获取用户对象
     */
    get() {
        let user = ext.readStorage('login_result');
        return user;
    },

    /**
     * 设置用户对象
     * @param {object} user 用户对象
     * @returns {boolean} 设置成功标记
     */
    set(user) {
        if (ext.isObject(user)) {
            ext.addStorage('login_result', user);
            return true;
        }
        return false;
    },

    /**
     * 获取登录信息
     */
    getLoginInfo() {
        let info = ext.readStorage('login_result');
        return info;
    },

    /**
     * 设置登录信息
     * @param {object} info 登录信息
     * @param {string} info.LoginName 登录账号
     * @param {string} info.Password 登录密码
     * @returns {boolean} 设置成功标记
     */
    setLoginInfo(info) {
        if (ext.isObject(info)) {
            ext.addStorage('login_info', info);
            return true;
        }
        return false;
    },

    /**
     * 清除用户信息缓存
     */
    clear() {
        ext.removeStorage('login_result');
        ext.removeStorage('login_info');
    },

    /**
     * 通过服务器获取用户信息
     */
    async getByServer() {
        let res = await request.sendToken({
            url: api.User.user.url,
            method: api.User.user.method
        });
        if (res.success) {
            this.set(res.data);
        }
        return res;
    }
}